package cloud

import (
	"fmt"

	"github.com/orjansv/master-code/simulator/sensor"
)

func printMessageEnergy(msg sensor.Message, timestamp string, ex, pu, pd, pub, pdb float64) {

	puStr := floatToString(pu)
	pdStr := floatToString(pd)
	pubStr := floatToString(pub)
	pdbStr := floatToString(pdb)

	fmt.Printf("MSG %s | G: %2d | S_ID: %3d | S_Addr: %3d | Msg_ID: %3d | \"cipher\": %s | B: %5t | Sig_Str: %.2f [dB] | Ex: %8.5f [mWs] | P_u: %s | P_d: %s | P_u(B): %s | P_d(B): %s |\n", timestamp, msg.GatewayID, msg.SensorID, msg.Address, msg.MessageID, msg.Ciphertext, msg.Boost, msg.SignalStrength, ex, puStr, pdStr, pubStr, pdbStr)
}

func printMessageSignalStrength(msg sensor.Message, timestamp string, avgSigStr float64) {
	fmt.Printf("MSG %s | G: %2d | S_ID: %3d | S_Addr: %3d | Msg_ID: %3d | \"cipher\": %s | B: %5t | Sig_Str: %.2f [dB] | Avg. Sig_Str: %.2f [dB] |\n", timestamp, msg.GatewayID, msg.SensorID, msg.Address, msg.MessageID, msg.Ciphertext, msg.Boost, msg.SignalStrength, avgSigStr)
}

func printMessageRetryCount(msg sensor.Message, timestamp string, retries int) {
	if retries < 0 {
		retries = 0
	}
	fmt.Printf("MSG %s | G: %2d | S_ID: %3d | S_Addr: %3d | Msg_ID: %3d | \"cipher\": %s | B: %5t | Sig_Str: %.2f [dB] | Retries: %d |\n", timestamp, msg.GatewayID, msg.SensorID, msg.Address, msg.MessageID, msg.Ciphertext, msg.Boost, msg.SignalStrength, retries)
}

func printMessageReliability(msg sensor.Message, timestamp string, wrel float64) {
	fmt.Printf("MSG %s | G: %2d | S_ID: %3d | S_Addr: %3d | Msg_ID: %3d | \"cipher\": %s | B: %5t | Sig_Str: %.2f [dB] | W_rel: %.2f |\n", timestamp, msg.GatewayID, msg.SensorID, msg.Address, msg.MessageID, msg.Ciphertext, msg.Boost, msg.SignalStrength, wrel)
}

func printGatewayChanged(sensorID, gatewayID int, reason string, verboseLevel int) {
	if verboseLevel > 0 {
		fmt.Printf("CMD Optimal gateway for sensor %3d is now gateway %2d because of %s\n", sensorID, gatewayID, reason)
	}
}

func floatToString(f float64) string {
	if f == -1.0 {
		return " N/A"
	}
	return fmt.Sprintf("%.2f", f)
}
