package utils

// MovingAverage is an implementation of a moving average window of float64s.
type MovingAverage struct {
	capacity     int
	data         []float64
	currentIndex int
	isFull       bool
}

// Insert inserts a float64 into the moving window.
func (maw *MovingAverage) Insert(value float64) {
	maw.data[maw.currentIndex] = value
	maw.currentIndex = (maw.currentIndex + 1) % maw.capacity

	if maw.currentIndex == 0 && !maw.isFull {
		maw.isFull = true
	}
}

// Average returns the average value of the moving window.
func (maw *MovingAverage) Average() float64 {
	sum := 0.0

	if maw.isFull {
		for _, val := range maw.data {
			sum += val
		}
		return sum / float64(maw.capacity)
	} else {
		for i := 0; i < maw.currentIndex; i++ {
			sum += maw.data[i]
		}
		return sum / float64(maw.currentIndex)
	}
}

// NewMAW initializes and returns a moving average window to the set capacity.
func NewMAW(capacity int) *MovingAverage {
	return &MovingAverage{
		capacity:     capacity,
		data:         make([]float64, capacity),
		currentIndex: 0,
		isFull:       false,
	}
}
